import * as nuxt_schema from 'nuxt/schema';
import { ScriptRegistry, NuxtUseScriptOptions, NuxtUseScriptInput, RegistryScripts } from '#nuxt-scripts';

interface ModuleOptions {
    /**
     * Register scripts globally.
     */
    register?: ScriptRegistry;
    /**
     * Default options for scripts.
     */
    defaultScriptOptions?: NuxtUseScriptOptions;
    /**
     * Register scripts that should be loaded globally on all pages.
     */
    globals?: (NuxtUseScriptInput | [NuxtUseScriptInput, NuxtUseScriptOptions])[];
    /**
     * Override the static script options for specific scripts based on their provided `key` or `src`.
     */
    overrides?: Record<keyof ScriptRegistry, Pick<NuxtUseScriptOptions, 'assetStrategy'>>;
    /** Configure the way scripts assets are exposed */
    assets?: {
        /**
         * The baseURL where scripts files are served.
         * @default '/_scripts/'
         */
        prefix?: string;
        /**
         * Scripts assets are exposed as public assets as part of the build.
         *
         * TODO Make configurable in future.
         */
        strategy?: 'public';
    };
    /**
     * Whether the module is enabled.
     *
     * @default true
     */
    enabled: boolean;
    /**
     * Enables debug mode.
     *
     * @false false
     */
    debug: boolean;
}
interface ModuleHooks {
    /**
     * Transform a script before it's registered.
     */
    'scripts:registry': (registry: RegistryScripts) => void | Promise<void>;
}
declare const _default: nuxt_schema.NuxtModule<ModuleOptions>;

export { type ModuleHooks, type ModuleOptions, _default as default };
