import { boolean, minLength, object, optional, string } from "valibot";
import { defu } from "defu";
import { useScript, validateScriptInputSchema } from "#imports";
export const CloudflareWebAnalyticsOptions = object({
  /**
   * The Cloudflare Web Analytics token.
   *
   * Required when used for the first time.
   */
  token: string([minLength(33)]),
  /**
   * Cloudflare Web Analytics enables measuring SPAs automatically by overriding the History API’s pushState function
   * and listening to the onpopstate. Hash-based router is not supported.
   *
   * @default true
   */
  spa: optional(boolean())
});
export function useScriptCloudflareWebAnalytics(options, _scriptOptions) {
  const scriptOptions = _scriptOptions || {};
  scriptOptions.beforeInit = () => {
    import.meta.dev && validateScriptInputSchema(CloudflareWebAnalyticsOptions, options);
    scriptOptions.beforeInit?.();
  };
  return useScript({
    "src": "https://static.cloudflareinsights.com/beacon.min.js",
    "data-cf-beacon": JSON.stringify(defu(options, { spa: true }))
  }, {
    ...scriptOptions,
    use() {
      return { __cfBeacon: window.__cfBeacon, __cfRl: window.__cfRl };
    }
  });
}
