import { boolean, literal, object, optional, string, union } from "valibot";
import { useScript, validateScriptInputSchema } from "#imports";
export const FathomAnalyticsOptions = object({
  "site": string(),
  // site is required
  "src": optional(string()),
  "data-spa": optional(union([literal("auto"), literal("history"), literal("hash")])),
  "data-auto": optional(boolean()),
  "data-canonical": optional(boolean()),
  "data-honor-dnt": optional(boolean())
});
export function useScriptFathomAnalytics(options, _scriptOptions) {
  const scriptOptions = _scriptOptions || {};
  scriptOptions.beforeInit = () => {
    import.meta.dev && validateScriptInputSchema(FathomAnalyticsOptions, options);
    scriptOptions.beforeInit?.();
  };
  return useScript({
    src: "https://cdn.usefathom.com/script.js",
    ...options
  }, {
    ...scriptOptions,
    use: () => window.fathom
  });
}
