import { literal, number, object, optional, string, union } from "valibot";
import { joinURL } from "ufo";
import { useScript, validateScriptInputSchema } from "#imports";
export const IntercomOptions = object({
  app_id: string(),
  api_base: optional(union([literal("https://api-iam.intercom.io"), literal("https://api-iam.eu.intercom.io"), literal("https://api-iam.au.intercom.io")])),
  name: optional(string()),
  email: optional(string()),
  user_id: optional(string()),
  // customizing the messenger
  alignment: optional(union([literal("left"), literal("right")])),
  horizontal_padding: optional(number()),
  vertical_padding: optional(number())
});
export function useScriptIntercom(options, _scriptOptions) {
  const scriptOptions = _scriptOptions || {};
  scriptOptions.beforeInit = () => {
    import.meta.dev && validateScriptInputSchema(IntercomOptions, options);
    if (import.meta.client)
      window.intercomSettings = options;
    scriptOptions.beforeInit?.();
  };
  return useScript({
    key: "intercom",
    src: options?.src || joinURL(`https://widget.intercom.io/widget`, options?.app_id || "")
  }, {
    ...scriptOptions,
    use() {
      return { Intercom: window.Intercom };
    }
  });
}
