import { object, optional, string } from "valibot";
import { useScript, validateScriptInputSchema } from "#imports";
export const SegmentOptions = object({
  writeKey: string(),
  analyticsKey: optional(string())
});
export function useScriptSegment(options, _scriptOptions) {
  const scriptOptions = _scriptOptions || {};
  scriptOptions.beforeInit = () => {
    import.meta.dev && validateScriptInputSchema(SegmentOptions, options);
    if (import.meta.client) {
      window.analytics = window.analytics || [];
      window.analytics.methods = ["track", "page", "identify", "group", "alias", "reset"];
      window.analytics.factory = function(method) {
        return function(...params) {
          const args = Array.prototype.slice.call(params);
          args.unshift(method);
          window.analytics.push(args);
          return window.analytics;
        };
      };
      for (let i = 0; i < window.analytics.methods.length; i++) {
        const key = window.analytics.methods[i];
        window.analytics[key] = window.analytics.factory(key);
      }
      window.analytics.page();
    }
    scriptOptions.beforeInit?.();
  };
  const analyticsKey = options?.analyticsKey || "analytics";
  return useScript({
    "key": "segment",
    "data-global-segment-analytics-key": analyticsKey,
    "src": options?.src || `https://cdn.segment.com/analytics.js/v1/${options?.writeKey}/analytics.min.js`
  }, {
    ...scriptOptions,
    use() {
      return { analytics: window[analyticsKey] };
    }
  });
}
